function Protwarbar:CreateOptions()
	local media = LibStub("LibSharedMedia-3.0")
	local textures = media:List("statusbar")
	local fonts = media:List("font")

	local L = LibStub("AceLocale-3.0"):GetLocale("Protwarbar")

	local options = {
		type = "group",
		name = "Prot War Bar",
		childGroups = "tab",
		args = {
			group1 = {
				name = L["General"],
				type = "group",
				order = 1,
				args = {
					enable = {
					  order = 1,
				      name = L["Enable"],
				      desc = L["Enables / disables the addon"],
					  type = "toggle",
				      set = function(info,val) self.db.profile.enabled = val Protwarbar:RefreshConfig() end,
				      get = function(info) return self.db.profile.enabled end
				    },
					locked = {
					  order = 2,
				      name = L["Lock frames"],
				      desc = L["When locked, you can not move the bar"],
					  type = "toggle",
				      set = function(info,val) self.db.profile.locked = val Protwarbar:RefreshConfig() end,
				      get = function(info) return self.db.profile.locked end
				    },
			    },
		    },
		    group2 = {
				name = L["Bar appearance"],
				type = "group",
				order = 2,
				args = {
					desc_pos = {
						type = 'header',
						name = L["Position"],
						order = 1,
					},
				    width = {
				        order = 3,
				    	name = L["Width"],
				    	desc = L["Width of rage bar"],
				    	type = "range",
				    	min = 5,
				    	max = 750,
				    	step = 1,
				      	set = function(info,val) self.db.profile.barWidth = val Protwarbar:RefreshConfig() end,
				      	get = function(info) return self.db.profile.barWidth end
					},
				    height = {
				        order = 4,
				    	name = L["Height"],
				    	desc = L["Height of bar"],
				    	type = "range",
				    	min = 5,
				    	max = 100,
				    	step = 1,
				      	set = function(info,val) self.db.profile.barHeight = val Protwarbar:RefreshConfig() end,
				      	get = function(info) return self.db.profile.barHeight end
					},
					desc_colour = {
						type = 'header',
						name = L["Bar colors"],
						order = 10,
					},					
				    color20 = {
				    	name = L["Color 0 - 19"],
				    	desc = L["Color 0 - 19"],
				    	type = "color",
				    	order = 15,
				    	hasAlpha = true,
				      	set = function(info, r, g, b, a) 
					      		self.db.profile.color20.r = r;
					      		self.db.profile.color20.g = g;
					      		self.db.profile.color20.b = b;
					      		self.db.profile.color20.a = a;
					      	 	Protwarbar:RefreshConfig() 
				      		end,
				      	get = function(info) return self.db.profile.color20.r, self.db.profile.color20.g,
				      								self.db.profile.color20.b, self.db.profile.color20.a 
				      		   end
					},
				    color60 = {
				    	name = L["Color 20 - 59"],
				    	desc = L["Color 20 - 59"],
				    	type = "color",
				    	order = 16,
				    	hasAlpha = true,
				      	set = function(info, r, g, b, a) 
					      		self.db.profile.color60.r = r;
					      		self.db.profile.color60.g = g;
					      		self.db.profile.color60.b = b;
					      		self.db.profile.color60.a = a;
					      	 	Protwarbar:RefreshConfig() 
				      		end,
				      	get = function(info) return self.db.profile.color60.r, self.db.profile.color60.g,
				      								self.db.profile.color60.b, self.db.profile.color60.a 
				      		   end
					},
					desc_colour2 = {
						type = 'description',
						name = " ",
						order = 20,
					},						
				    color100 = {
				        order = 27,
				    	name = L["Color 60 - 99"],
				    	desc = L["Color 60 - 99"],
				    	type = "color",
				    	hasAlpha = true,
				      	set = function(info, r, g, b, a) 
					      		self.db.profile.color100.r = r;
					      		self.db.profile.color100.g = g;
					      		self.db.profile.color100.b = b;
					      		self.db.profile.color100.a = a;
					      	 	Protwarbar:RefreshConfig() 
				      		end,
				      	get = function(info) return self.db.profile.color100.r, self.db.profile.color100.g,
				      								self.db.profile.color100.b, self.db.profile.color100.a 
				      		   end
					},
					colorMax = {
				        order = 28,
				    	name = L["Color full bar"],
				    	desc = L["Color full bar"],
				    	type = "color",
				    	hasAlpha = true,
				      	set = function(info, r, g, b, a) 
					      		self.db.profile.colorMax.r = r;
					      		self.db.profile.colorMax.g = g;
					      		self.db.profile.colorMax.b = b;
					      		self.db.profile.colorMax.a = a;
					      	 	Protwarbar:RefreshConfig() 
				      		end,
				      	get = function(info) return self.db.profile.colorMax.r, self.db.profile.colorMax.g,
				      								self.db.profile.colorMax.b, self.db.profile.colorMax.a 
				      		   end
					},
					desc_bg_head = {
						type = 'header',
						name = L["Bar colors"],
						order = 30,
					},
				    barTexture = {
				    	name = L["Texture"],
				    	desc = L["Texture for ragebar"],
				    	type = "select",
				    	values = textures,
				    	order = 31,
				      	set = function(info, v)
				      			self.db.profile.barTexture = media:List("statusbar")[v]
					      	 	Protwarbar:RefreshConfig() 
				      		end,
				      	get = function(info) return GetLSMIndex("statusbar", self.db.profile.barTexture) end
					},
					desc_colour32 = {
						type = 'description',
						name = " ",
						order = 32,
					},						
				    bg = {
				    	name = L["Background color"],
				    	desc = L["Color of bar Background"],
				    	type = "color",
				    	order = 33,
				    	hasAlpha = true,
				      	set = function(info, r, g, b, a) 
					      		self.db.profile.bg.r = r;
					      		self.db.profile.bg.g = g;
					      		self.db.profile.bg.b = b;
					      		self.db.profile.bg.a = a;
					      	 	Protwarbar:RefreshConfig() 
				      		end,
				      	get = function(info) return self.db.profile.bg.r, self.db.profile.bg.g,
				      								self.db.profile.bg.b, self.db.profile.bg.a 
				      		   end
					},

					desc_bg = {
						type = 'header',
						name = L["Bar text"],
						order = 50,
					},						
				    barFont = {
				    	name = L["Font"],
				    	desc = L["Font for ragebar"],
				    	type = "select",
				    	values = fonts,
				    	order = 51,
				      	set = function(info, v)
				      			self.db.profile.barFont = media:List("font")[v]
					      	 	Protwarbar:RefreshConfig() 
				      		end,
				      	get = function(info) return GetLSMIndex("font", self.db.profile.barFont) end
					},
					desc_52 = {
						type = 'description',
						name = " ",
						order = 52,
					},						
				    fontsize = {
				        order = 53,
				    	name = L["Font Size"],
				    	desc = L["Size of the font used on the ragebar"],
				    	type = "range",
				    	min = 3,
				    	max = 50,
				    	step = 1,
				      	set = function(info,val) self.db.profile.barFontsize = val Protwarbar:RefreshConfig() end,
				      	get = function(info) return self.db.profile.barFontsize end
					},					
				},
			},
			group3 = {
				name = L["Icons"],
				type = "group",
				order = 3,
				args = {
					desc_pos = {
						type = 'header',
						name = L["Icons"],
						order = 1,
					},
				    iconsize = {
				        order = 3,
				    	name = L["Size"],
				    	desc = L["Size of the icons"],
				    	type = "range",
				    	min = 5,
				    	max = 100,
				    	step = 1,
				      	set = function(info,val) self.db.profile.iconsize = val Protwarbar:RefreshConfig() end,
				      	get = function(info) return self.db.profile.iconsize end
					},
				},
			},
		},
	}

	return options
end

function GetLSMIndex(t, value)
	local media = LibStub("LibSharedMedia-3.0")

	for k, v in pairs(media:List(t)) do
		if v == value then
			return k
		end
	end
	return nil
end